@@ -24,7 +24,6 @@
 #include "grantleetheme_export.h"
 
 namespace GrantleeTheme {
-
 class GrantleeKi18nLocalizer;
 class EnginePrivate;
 class GRANTLEETHEME_EXPORT Engine : public Grantlee::Engine
@@ -33,14 +32,13 @@ class GRANTLEETHEME_EXPORT Engine : public Grantlee::Engine
 
 public:
     explicit Engine(QObject *parent = nullptr);
-    ~Engine() Q_DECL_OVERRIDE;
+    ~Engine() override;
 
     QSharedPointer<GrantleeKi18nLocalizer> localizer() const;
 
 private:
     EnginePrivate *const d;
 };
-
 }
 
 #endif
